@@ -23,7 +23,9 @@ from google.cloud.container_v1.services.cluster_manager.async_client import (
 
 from google.cloud.container_v1.types.cluster_service import AcceleratorConfig
 from google.cloud.container_v1.types.cluster_service import AddonsConfig
+from google.cloud.container_v1.types.cluster_service import AdvancedMachineFeatures
 from google.cloud.container_v1.types.cluster_service import AuthenticatorGroupsConfig
+from google.cloud.container_v1.types.cluster_service import Autopilot
 from google.cloud.container_v1.types.cluster_service import (
     AutoprovisioningNodePoolDefaults,
 )
@@ -36,6 +38,7 @@ from google.cloud.container_v1.types.cluster_service import Cluster
 from google.cloud.container_v1.types.cluster_service import ClusterAutoscaling
 from google.cloud.container_v1.types.cluster_service import ClusterUpdate
 from google.cloud.container_v1.types.cluster_service import CompleteIPRotationRequest
+from google.cloud.container_v1.types.cluster_service import ConfidentialNodes
 from google.cloud.container_v1.types.cluster_service import ConfigConnectorConfig
 from google.cloud.container_v1.types.cluster_service import CreateClusterRequest
 from google.cloud.container_v1.types.cluster_service import CreateNodePoolRequest
@@ -45,6 +48,12 @@ from google.cloud.container_v1.types.cluster_service import DefaultSnatStatus
 from google.cloud.container_v1.types.cluster_service import DeleteClusterRequest
 from google.cloud.container_v1.types.cluster_service import DeleteNodePoolRequest
 from google.cloud.container_v1.types.cluster_service import DnsCacheConfig
+from google.cloud.container_v1.types.cluster_service import DNSConfig
+from google.cloud.container_v1.types.cluster_service import (
+    GcePersistentDiskCsiDriverConfig,
+)
+from google.cloud.container_v1.types.cluster_service import GcfsConfig
+from google.cloud.container_v1.types.cluster_service import GcpFilestoreCsiDriverConfig
 from google.cloud.container_v1.types.cluster_service import GetClusterRequest
 from google.cloud.container_v1.types.cluster_service import GetJSONWebKeysRequest
 from google.cloud.container_v1.types.cluster_service import GetJSONWebKeysResponse
@@ -55,11 +64,13 @@ from google.cloud.container_v1.types.cluster_service import GetOperationRequest
 from google.cloud.container_v1.types.cluster_service import GetServerConfigRequest
 from google.cloud.container_v1.types.cluster_service import HorizontalPodAutoscaling
 from google.cloud.container_v1.types.cluster_service import HttpLoadBalancing
+from google.cloud.container_v1.types.cluster_service import ILBSubsettingConfig
 from google.cloud.container_v1.types.cluster_service import IntraNodeVisibilityConfig
 from google.cloud.container_v1.types.cluster_service import IPAllocationPolicy
 from google.cloud.container_v1.types.cluster_service import Jwk
 from google.cloud.container_v1.types.cluster_service import KubernetesDashboard
 from google.cloud.container_v1.types.cluster_service import LegacyAbac
+from google.cloud.container_v1.types.cluster_service import LinuxNodeConfig
 from google.cloud.container_v1.types.cluster_service import ListClustersRequest
 from google.cloud.container_v1.types.cluster_service import ListClustersResponse
 from google.cloud.container_v1.types.cluster_service import ListNodePoolsRequest
@@ -70,6 +81,9 @@ from google.cloud.container_v1.types.cluster_service import ListUsableSubnetwork
 from google.cloud.container_v1.types.cluster_service import (
     ListUsableSubnetworksResponse,
 )
+from google.cloud.container_v1.types.cluster_service import LoggingComponentConfig
+from google.cloud.container_v1.types.cluster_service import LoggingConfig
+from google.cloud.container_v1.types.cluster_service import MaintenanceExclusionOptions
 from google.cloud.container_v1.types.cluster_service import MaintenancePolicy
 from google.cloud.container_v1.types.cluster_service import MaintenanceWindow
 from google.cloud.container_v1.types.cluster_service import MasterAuth
@@ -77,14 +91,22 @@ from google.cloud.container_v1.types.cluster_service import (
     MasterAuthorizedNetworksConfig,
 )
 from google.cloud.container_v1.types.cluster_service import MaxPodsConstraint
+from google.cloud.container_v1.types.cluster_service import MeshCertificates
+from google.cloud.container_v1.types.cluster_service import MonitoringComponentConfig
+from google.cloud.container_v1.types.cluster_service import MonitoringConfig
 from google.cloud.container_v1.types.cluster_service import NetworkConfig
 from google.cloud.container_v1.types.cluster_service import NetworkPolicy
 from google.cloud.container_v1.types.cluster_service import NetworkPolicyConfig
 from google.cloud.container_v1.types.cluster_service import NodeConfig
+from google.cloud.container_v1.types.cluster_service import NodeConfigDefaults
+from google.cloud.container_v1.types.cluster_service import NodeKubeletConfig
 from google.cloud.container_v1.types.cluster_service import NodeManagement
+from google.cloud.container_v1.types.cluster_service import NodeNetworkConfig
 from google.cloud.container_v1.types.cluster_service import NodePool
 from google.cloud.container_v1.types.cluster_service import NodePoolAutoscaling
+from google.cloud.container_v1.types.cluster_service import NodePoolDefaults
 from google.cloud.container_v1.types.cluster_service import NodeTaint
+from google.cloud.container_v1.types.cluster_service import NotificationConfig
 from google.cloud.container_v1.types.cluster_service import Operation
 from google.cloud.container_v1.types.cluster_service import OperationProgress
 from google.cloud.container_v1.types.cluster_service import PrivateClusterConfig
@@ -100,7 +122,9 @@ from google.cloud.container_v1.types.cluster_service import (
     RollbackNodePoolUpgradeRequest,
 )
 from google.cloud.container_v1.types.cluster_service import SandboxConfig
+from google.cloud.container_v1.types.cluster_service import SecurityBulletinEvent
 from google.cloud.container_v1.types.cluster_service import ServerConfig
+from google.cloud.container_v1.types.cluster_service import ServiceExternalIPsConfig
 from google.cloud.container_v1.types.cluster_service import SetAddonsConfigRequest
 from google.cloud.container_v1.types.cluster_service import SetLabelsRequest
 from google.cloud.container_v1.types.cluster_service import SetLegacyAbacRequest
@@ -123,20 +147,28 @@ from google.cloud.container_v1.types.cluster_service import TimeWindow
 from google.cloud.container_v1.types.cluster_service import UpdateClusterRequest
 from google.cloud.container_v1.types.cluster_service import UpdateMasterRequest
 from google.cloud.container_v1.types.cluster_service import UpdateNodePoolRequest
+from google.cloud.container_v1.types.cluster_service import UpgradeAvailableEvent
+from google.cloud.container_v1.types.cluster_service import UpgradeEvent
 from google.cloud.container_v1.types.cluster_service import UsableSubnetwork
 from google.cloud.container_v1.types.cluster_service import (
     UsableSubnetworkSecondaryRange,
 )
 from google.cloud.container_v1.types.cluster_service import VerticalPodAutoscaling
+from google.cloud.container_v1.types.cluster_service import VirtualNIC
 from google.cloud.container_v1.types.cluster_service import WorkloadIdentityConfig
 from google.cloud.container_v1.types.cluster_service import WorkloadMetadataConfig
+from google.cloud.container_v1.types.cluster_service import DatapathProvider
+from google.cloud.container_v1.types.cluster_service import PrivateIPv6GoogleAccess
+from google.cloud.container_v1.types.cluster_service import UpgradeResourceType
 
 __all__ = (
     "ClusterManagerClient",
     "ClusterManagerAsyncClient",
     "AcceleratorConfig",
     "AddonsConfig",
+    "AdvancedMachineFeatures",
     "AuthenticatorGroupsConfig",
+    "Autopilot",
     "AutoprovisioningNodePoolDefaults",
     "AutoUpgradeOptions",
     "BinaryAuthorization",
@@ -147,6 +179,7 @@ __all__ = (
     "ClusterAutoscaling",
     "ClusterUpdate",
     "CompleteIPRotationRequest",
+    "ConfidentialNodes",
     "ConfigConnectorConfig",
     "CreateClusterRequest",
     "CreateNodePoolRequest",
@@ -156,6 +189,10 @@ __all__ = (
     "DeleteClusterRequest",
     "DeleteNodePoolRequest",
     "DnsCacheConfig",
+    "DNSConfig",
+    "GcePersistentDiskCsiDriverConfig",
+    "GcfsConfig",
+    "GcpFilestoreCsiDriverConfig",
     "GetClusterRequest",
     "GetJSONWebKeysRequest",
     "GetJSONWebKeysResponse",
@@ -166,11 +203,13 @@ __all__ = (
     "GetServerConfigRequest",
     "HorizontalPodAutoscaling",
     "HttpLoadBalancing",
+    "ILBSubsettingConfig",
     "IntraNodeVisibilityConfig",
     "IPAllocationPolicy",
     "Jwk",
     "KubernetesDashboard",
     "LegacyAbac",
+    "LinuxNodeConfig",
     "ListClustersRequest",
     "ListClustersResponse",
     "ListNodePoolsRequest",
@@ -179,19 +218,30 @@ __all__ = (
     "ListOperationsResponse",
     "ListUsableSubnetworksRequest",
     "ListUsableSubnetworksResponse",
+    "LoggingComponentConfig",
+    "LoggingConfig",
+    "MaintenanceExclusionOptions",
     "MaintenancePolicy",
     "MaintenanceWindow",
     "MasterAuth",
     "MasterAuthorizedNetworksConfig",
     "MaxPodsConstraint",
+    "MeshCertificates",
+    "MonitoringComponentConfig",
+    "MonitoringConfig",
     "NetworkConfig",
     "NetworkPolicy",
     "NetworkPolicyConfig",
     "NodeConfig",
+    "NodeConfigDefaults",
+    "NodeKubeletConfig",
     "NodeManagement",
+    "NodeNetworkConfig",
     "NodePool",
     "NodePoolAutoscaling",
+    "NodePoolDefaults",
     "NodeTaint",
+    "NotificationConfig",
     "Operation",
     "OperationProgress",
     "PrivateClusterConfig",
@@ -203,7 +253,9 @@ __all__ = (
     "ResourceUsageExportConfig",
     "RollbackNodePoolUpgradeRequest",
     "SandboxConfig",
+    "SecurityBulletinEvent",
     "ServerConfig",
+    "ServiceExternalIPsConfig",
     "SetAddonsConfigRequest",
     "SetLabelsRequest",
     "SetLegacyAbacRequest",
@@ -224,9 +276,15 @@ __all__ = (
     "UpdateClusterRequest",
     "UpdateMasterRequest",
     "UpdateNodePoolRequest",
+    "UpgradeAvailableEvent",
+    "UpgradeEvent",
     "UsableSubnetwork",
     "UsableSubnetworkSecondaryRange",
     "VerticalPodAutoscaling",
+    "VirtualNIC",
     "WorkloadIdentityConfig",
     "WorkloadMetadataConfig",
+    "DatapathProvider",
+    "PrivateIPv6GoogleAccess",
+    "UpgradeResourceType",
 )
