@@ -19,7 +19,9 @@ from .services.cluster_manager import ClusterManagerAsyncClient
 
 from .types.cluster_service import AcceleratorConfig
 from .types.cluster_service import AddonsConfig
+from .types.cluster_service import AdvancedMachineFeatures
 from .types.cluster_service import AuthenticatorGroupsConfig
+from .types.cluster_service import Autopilot
 from .types.cluster_service import AutoprovisioningNodePoolDefaults
 from .types.cluster_service import AutoUpgradeOptions
 from .types.cluster_service import BinaryAuthorization
@@ -30,6 +32,7 @@ from .types.cluster_service import Cluster
 from .types.cluster_service import ClusterAutoscaling
 from .types.cluster_service import ClusterUpdate
 from .types.cluster_service import CompleteIPRotationRequest
+from .types.cluster_service import ConfidentialNodes
 from .types.cluster_service import ConfigConnectorConfig
 from .types.cluster_service import CreateClusterRequest
 from .types.cluster_service import CreateNodePoolRequest
@@ -39,6 +42,10 @@ from .types.cluster_service import DefaultSnatStatus
 from .types.cluster_service import DeleteClusterRequest
 from .types.cluster_service import DeleteNodePoolRequest
 from .types.cluster_service import DnsCacheConfig
+from .types.cluster_service import DNSConfig
+from .types.cluster_service import GcePersistentDiskCsiDriverConfig
+from .types.cluster_service import GcfsConfig
+from .types.cluster_service import GcpFilestoreCsiDriverConfig
 from .types.cluster_service import GetClusterRequest
 from .types.cluster_service import GetJSONWebKeysRequest
 from .types.cluster_service import GetJSONWebKeysResponse
@@ -49,11 +56,13 @@ from .types.cluster_service import GetOperationRequest
 from .types.cluster_service import GetServerConfigRequest
 from .types.cluster_service import HorizontalPodAutoscaling
 from .types.cluster_service import HttpLoadBalancing
+from .types.cluster_service import ILBSubsettingConfig
 from .types.cluster_service import IntraNodeVisibilityConfig
 from .types.cluster_service import IPAllocationPolicy
 from .types.cluster_service import Jwk
 from .types.cluster_service import KubernetesDashboard
 from .types.cluster_service import LegacyAbac
+from .types.cluster_service import LinuxNodeConfig
 from .types.cluster_service import ListClustersRequest
 from .types.cluster_service import ListClustersResponse
 from .types.cluster_service import ListNodePoolsRequest
@@ -62,19 +71,30 @@ from .types.cluster_service import ListOperationsRequest
 from .types.cluster_service import ListOperationsResponse
 from .types.cluster_service import ListUsableSubnetworksRequest
 from .types.cluster_service import ListUsableSubnetworksResponse
+from .types.cluster_service import LoggingComponentConfig
+from .types.cluster_service import LoggingConfig
+from .types.cluster_service import MaintenanceExclusionOptions
 from .types.cluster_service import MaintenancePolicy
 from .types.cluster_service import MaintenanceWindow
 from .types.cluster_service import MasterAuth
 from .types.cluster_service import MasterAuthorizedNetworksConfig
 from .types.cluster_service import MaxPodsConstraint
+from .types.cluster_service import MeshCertificates
+from .types.cluster_service import MonitoringComponentConfig
+from .types.cluster_service import MonitoringConfig
 from .types.cluster_service import NetworkConfig
 from .types.cluster_service import NetworkPolicy
 from .types.cluster_service import NetworkPolicyConfig
 from .types.cluster_service import NodeConfig
+from .types.cluster_service import NodeConfigDefaults
+from .types.cluster_service import NodeKubeletConfig
 from .types.cluster_service import NodeManagement
+from .types.cluster_service import NodeNetworkConfig
 from .types.cluster_service import NodePool
 from .types.cluster_service import NodePoolAutoscaling
+from .types.cluster_service import NodePoolDefaults
 from .types.cluster_service import NodeTaint
+from .types.cluster_service import NotificationConfig
 from .types.cluster_service import Operation
 from .types.cluster_service import OperationProgress
 from .types.cluster_service import PrivateClusterConfig
@@ -86,7 +106,9 @@ from .types.cluster_service import ResourceLimit
 from .types.cluster_service import ResourceUsageExportConfig
 from .types.cluster_service import RollbackNodePoolUpgradeRequest
 from .types.cluster_service import SandboxConfig
+from .types.cluster_service import SecurityBulletinEvent
 from .types.cluster_service import ServerConfig
+from .types.cluster_service import ServiceExternalIPsConfig
 from .types.cluster_service import SetAddonsConfigRequest
 from .types.cluster_service import SetLabelsRequest
 from .types.cluster_service import SetLegacyAbacRequest
@@ -107,18 +129,26 @@ from .types.cluster_service import TimeWindow
 from .types.cluster_service import UpdateClusterRequest
 from .types.cluster_service import UpdateMasterRequest
 from .types.cluster_service import UpdateNodePoolRequest
+from .types.cluster_service import UpgradeAvailableEvent
+from .types.cluster_service import UpgradeEvent
 from .types.cluster_service import UsableSubnetwork
 from .types.cluster_service import UsableSubnetworkSecondaryRange
 from .types.cluster_service import VerticalPodAutoscaling
+from .types.cluster_service import VirtualNIC
 from .types.cluster_service import WorkloadIdentityConfig
 from .types.cluster_service import WorkloadMetadataConfig
+from .types.cluster_service import DatapathProvider
+from .types.cluster_service import PrivateIPv6GoogleAccess
+from .types.cluster_service import UpgradeResourceType
 
 __all__ = (
     "ClusterManagerAsyncClient",
     "AcceleratorConfig",
     "AddonsConfig",
+    "AdvancedMachineFeatures",
     "AuthenticatorGroupsConfig",
     "AutoUpgradeOptions",
+    "Autopilot",
     "AutoprovisioningNodePoolDefaults",
     "BinaryAuthorization",
     "CancelOperationRequest",
@@ -129,15 +159,21 @@ __all__ = (
     "ClusterManagerClient",
     "ClusterUpdate",
     "CompleteIPRotationRequest",
+    "ConfidentialNodes",
     "ConfigConnectorConfig",
     "CreateClusterRequest",
     "CreateNodePoolRequest",
+    "DNSConfig",
     "DailyMaintenanceWindow",
     "DatabaseEncryption",
+    "DatapathProvider",
     "DefaultSnatStatus",
     "DeleteClusterRequest",
     "DeleteNodePoolRequest",
     "DnsCacheConfig",
+    "GcePersistentDiskCsiDriverConfig",
+    "GcfsConfig",
+    "GcpFilestoreCsiDriverConfig",
     "GetClusterRequest",
     "GetJSONWebKeysRequest",
     "GetJSONWebKeysResponse",
@@ -148,11 +184,13 @@ __all__ = (
     "GetServerConfigRequest",
     "HorizontalPodAutoscaling",
     "HttpLoadBalancing",
+    "ILBSubsettingConfig",
     "IPAllocationPolicy",
     "IntraNodeVisibilityConfig",
     "Jwk",
     "KubernetesDashboard",
     "LegacyAbac",
+    "LinuxNodeConfig",
     "ListClustersRequest",
     "ListClustersResponse",
     "ListNodePoolsRequest",
@@ -161,23 +199,35 @@ __all__ = (
     "ListOperationsResponse",
     "ListUsableSubnetworksRequest",
     "ListUsableSubnetworksResponse",
+    "LoggingComponentConfig",
+    "LoggingConfig",
+    "MaintenanceExclusionOptions",
     "MaintenancePolicy",
     "MaintenanceWindow",
     "MasterAuth",
     "MasterAuthorizedNetworksConfig",
     "MaxPodsConstraint",
+    "MeshCertificates",
+    "MonitoringComponentConfig",
+    "MonitoringConfig",
     "NetworkConfig",
     "NetworkPolicy",
     "NetworkPolicyConfig",
     "NodeConfig",
+    "NodeConfigDefaults",
+    "NodeKubeletConfig",
     "NodeManagement",
+    "NodeNetworkConfig",
     "NodePool",
     "NodePoolAutoscaling",
+    "NodePoolDefaults",
     "NodeTaint",
+    "NotificationConfig",
     "Operation",
     "OperationProgress",
     "PrivateClusterConfig",
     "PrivateClusterMasterGlobalAccessConfig",
+    "PrivateIPv6GoogleAccess",
     "RecurringTimeWindow",
     "ReleaseChannel",
     "ReservationAffinity",
@@ -185,7 +235,9 @@ __all__ = (
     "ResourceUsageExportConfig",
     "RollbackNodePoolUpgradeRequest",
     "SandboxConfig",
+    "SecurityBulletinEvent",
     "ServerConfig",
+    "ServiceExternalIPsConfig",
     "SetAddonsConfigRequest",
     "SetLabelsRequest",
     "SetLegacyAbacRequest",
@@ -206,9 +258,13 @@ __all__ = (
     "UpdateClusterRequest",
     "UpdateMasterRequest",
     "UpdateNodePoolRequest",
+    "UpgradeAvailableEvent",
+    "UpgradeEvent",
+    "UpgradeResourceType",
     "UsableSubnetwork",
     "UsableSubnetworkSecondaryRange",
     "VerticalPodAutoscaling",
+    "VirtualNIC",
     "WorkloadIdentityConfig",
     "WorkloadMetadataConfig",
 )
